==> haskell-linear-1.22-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.22
visibility:           public
id:                   linear-1.22-93QZRHQrc26HIUkA9voIVI
key:                  linear-1.22-93QZRHQrc26HIUkA9voIVI
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  b6f715d294c7cb6c6f7b77c688d331d2
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-1.22
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-1.22
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.22-93QZRHQrc26HIUkA9voIVI
depends:
    adjunctions-4.4.2-IxPvhBUm8BND18mQlRgcRp base-4.17.2.1
    base-orphans-0.8.8.2-FEffy3DtXbz5YHgxbB6Zcu binary-0.8.9.1
    bytes-0.17.4-zMUOkKylj3A9TXaWqKVho
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    deepseq-1.4.8.0 distributive-0.6.2.1-2YiBzgLXCd2kHPlGPsZiv
    ghc-prim-0.9.1 hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    indexed-traversable-0.1.4-AIrw26zjgKT4obC66VIWQz
    lens-5.2.3-DnVNcFpsuwMCXFWImXsY2L
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    reflection-2.1.8-IzsXWlHjt4TESz0UPz2Oez
    semigroupoids-6.0.1-KJLmU5mrNHLKm7QTvtklBq
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-1.22-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.22
visibility:           public
id:                   linear-1.22-JcEFNNjYecSEXKtCgJXrFO
key:                  linear-1.22-JcEFNNjYecSEXKtCgJXrFO
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  c4ef63c9c29f4f5e3c758e3e122a8984
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-1.22
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-1.22
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.22-JcEFNNjYecSEXKtCgJXrFO
depends:
    adjunctions-4.4.3-ArvoXeENUnN7CtRvS3NtFU base-4.17.2.1
    base-orphans-0.9.0-ALpWuDlnq7UGqqfUTrdEaR binary-0.8.9.1
    bytes-0.17.4-7sKyZTa6WIPCmTrmKup6dc
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    deepseq-1.4.8.0 distributive-0.6.2.1-Gc8PUWM0btz9ZAWKtORd6a
    ghc-prim-0.9.1 hashable-1.4.4.0-5O85VrI4oZ4EDBPYdTgwgk
    indexed-traversable-0.1.4-5uvxwew3Uwx9YqKKWPbxP3
    lens-5.2.3-CV81uxSR0PiAcO8XtynZEb
    random-1.2.1.2-22OpplVYpUz38cGfsZmdPY
    reflection-2.1.8-9Ke1IWdp93KDez6btU0gXt
    semigroupoids-6.0.1-4tZ3GUdbU6C6aZsHetCI4X
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
